==> gulp-lcov-to-html-0.0.3.tgz: package/lib/tree.js <==
var newDirectory, path, summarizeCoverage, totalSection,
  hasProp = {}.hasOwnProperty,
  slice = [].slice;

path = require('path');

totalSection = function(sectionName, tree, subtree) {
  var subSection, treeSection;
  treeSection = tree.stats[sectionName];
  subSection = subtree.stats[sectionName];
  treeSection.hit += subSection.hit;
  treeSection.total += subSection.total;
  if (treeSection.total !== 0) {
    return treeSection.percentage = Math.round(treeSection.hit / treeSection.total * 1000) / 10;
  } else {
    return treeSection.percentage = -1;
  }
};

summarizeCoverage = function(tree) {
  var item, ref, subtree;
  if (tree.type === 'directory') {
    ref = tree.children;
    for (item in ref) {
      if (!hasProp.call(ref, item)) continue;
      subtree = ref[item];
      summarizeCoverage(subtree);
      totalSection('lines', tree, subtree);
      totalSection('branches', tree, subtree);
      totalSection('functions', tree, subtree);
    }
  }
};

newDirectory = function(name) {
  return {
    name: name,
    type: 'directory',
    children: {},
    stats: {
      lines: {
        hit: 0,
        total: 0,
        percentage: 0
      },
      branches: {
        hit: 0,
        total: 0,
        percentage: 0
      },
      functions: {
        hit: 0,
        total: 0,
        percentage: 0
      }
    }
  };
};

module.exports = function(linearMap) {
  var base, directory, file, fileName, filePath, i, info, j, keys, len, piece, ref, tree;
  tree = newDirectory('');
  for (file in linearMap) {
    info = linearMap[file];
    ref = file.split(path.sep).map(function(v) {
      return v.trim();
    }).filter(function(v) {
      return v.length > 0;
    }), filePath = 2 <= ref.length ? slice.call(ref, 0, i = ref.length - 1) : (i = 0, []), fileName = ref[i++];
    directory = tree;
    for (j = 0, len = filePath.length; j < len; j++) {
      piece = filePath[j];
      directory = (base = directory.children)[piece] != null ? base[piece] : base[piece] = newDirectory(piece);
    }
    directory.children[fileName] = info;
  }
  summarizeCoverage(tree);
  while ((tree != null) && tree.type === 'directory' && (keys = Object.keys(tree.children)).length === 1) {
    tree = tree.children[keys[0]];
  }
  return tree;
};

==> gulp-lcov-to-html-2.0.0.tgz: package/lib/tree.js <==
var newDirectory, path, summarizeCoverage, totalSection,
  hasProp = {}.hasOwnProperty,
  slice = [].slice;

path = require('path');

totalSection = function(sectionName, tree, subtree) {
  var subSection, treeSection;
  treeSection = tree.stats[sectionName];
  subSection = subtree.stats[sectionName];
  treeSection.hit += subSection.hit;
  treeSection.total += subSection.total;
  if (treeSection.total !== 0) {
    return treeSection.percentage = Math.round(treeSection.hit / treeSection.total * 1000) / 10;
  } else {
    return treeSection.percentage = -1;
  }
};

summarizeCoverage = function(tree) {
  var item, ref, subtree;
  if (tree.type === 'directory') {
    ref = tree.children;
    for (item in ref) {
      if (!hasProp.call(ref, item)) continue;
      subtree = ref[item];
      summarizeCoverage(subtree);
      totalSection('lines', tree, subtree);
      totalSection('branches', tree, subtree);
      totalSection('functions', tree, subtree);
    }
  }
};

newDirectory = function(name) {
  return {
    name: name,
    type: 'directory',
    children: {},
    stats: {
      lines: {
        hit: 0,
        total: 0,
        percentage: 0
      },
      branches: {
        hit: 0,
        total: 0,
        percentage: 0
      },
      functions: {
        hit: 0,
        total: 0,
        percentage: 0
      }
    }
  };
};

module.exports = function(linearMap) {
  var base, directory, file, fileName, filePath, i, info, j, keys, len, piece, ref, tree;
  tree = newDirectory('<root>');
  for (file in linearMap) {
    info = linearMap[file];
    ref = file.split(path.sep).map(function(v) {
      return v.trim();
    }).filter(function(v) {
      return v.length > 0;
    }), filePath = 2 <= ref.length ? slice.call(ref, 0, i = ref.length - 1) : (i = 0, []), fileName = ref[i++];
    directory = tree;
    for (j = 0, len = filePath.length; j < len; j++) {
      piece = filePath[j];
      directory = (base = directory.children)[piece] != null ? base[piece] : base[piece] = newDirectory(piece);
    }
    directory.children[fileName] = info;
  }
  summarizeCoverage(tree);
  while ((tree != null) && tree.type === 'directory' && (keys = Object.keys(tree.children)).length === 1) {
    tree = tree.children[keys[0]];
  }
  return tree;
};
